operation

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 24, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Clone

func Clone(op huma.Operation) huma.Operation

Clone creates a 1-level deep copy of an operation. It clones slices and maps in the operation, but doesn't go deeper. It's used for fan-out registration middlewares to pass a copy of the operation to branch where it can be modified without affecting the siblings. The depth of the cloning is enough for the modifications made by library-provided operation handlers.

Types

This section is empty.

Jump to