Documentation
¶
Index ¶
Constants ¶
const KeyTransformers = internal.PkgID + "transformers"
KeyTransformers is a key for huma.Context that stores transformers that should be applied after the response is generated. It's filled with a slice of transformers stored in APIGen instance that was used for operation registration. It's for internal library usage, and you are not supposed to modify it.
Variables ¶
This section is empty.
Functions ¶
func GetTransformers ¶
func GetTransformers(ctx huma.Context) []huma.Transformer
GetTransformers returns transformers stored in the context.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.