Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Clone ¶
Clone creates a 1-level deep copy of an operation. It clones slices and maps in the operation, but doesn't go deeper. It's used for fan-out registration middlewares to pass a copy of the operation to branch where it can be modified without affecting the siblings. The depth of the cloning is enough for the modifications made by library-provided operation handlers.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.